from wagtail.wagtailcore.blocks import (
    StructBlock,
    StreamBlock,
    TextBlock,
)
from wagtail.wagtaildocs.blocks import DocumentChooserBlock


class DocumentActionItemBlock(StructBlock):
    label = TextBlock(required=True)
    document = DocumentChooserBlock(required=True)

    class Meta:
        icon = 'fa-file'
        template = 'blocks/document_action_item.html'
        help_text = 'Select a document and label for the button.'


class URLActionItemBlock(StructBlock):
    label = TextBlock(required=True)
    url = TextBlock(required=True)

    class Meta:
        icon = 'fa-link'
        template = 'blocks/url_action_item.html'
        help_text = 'Select a URL and label for the button.'


class PlaceholderBlock(StructBlock):
    pass

    class Meta:
        icon = 'fa-square-o'
        template = 'blocks/placeholder_action_item.html'
        help_text = 'Empty placeholder to align buttons in rows.'


class ActionItemStreamBlock(StreamBlock):
    document_button = DocumentActionItemBlock(icon='fa-file')
    url_button = URLActionItemBlock(icon='fa-link')
    placeholder = PlaceholderBlock(icon='fa-square-o')


class ButtonSectionBlock(StructBlock):
    action_items = ActionItemStreamBlock(help_text='A button or URL within a button section.')

    class Meta:
        icon = 'fa-list'
        template = 'blocks/button_section.html'
        help_text = 'Sections divide the action item area into rows.'


class ButtonBlock(StreamBlock):
    button_section = ButtonSectionBlock()

    class Meta:
        help_text = "A row of buttons in the expanded grid item area."



# -*- coding: utf-8 -*-
# Generated by Django 1.10.1 on 2016-09-12 18:57
from __future__ import unicode_literals

from django.db import migrations, models
import django.db.models.deletion
import modelcluster.contrib.taggit
import modelcluster.fields
import wagtail.wagtailcore.blocks
import wagtail.wagtailcore.fields
import wagtail.wagtaildocs.blocks


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        ('taggit', '0002_auto_20150616_2121'),
        ('wagtailcore', '0029_unicode_slugfield_dj19'),
        ('wagtailimages', '0013_make_rendition_upload_callable'),
    ]

    operations = [
        migrations.CreateModel(
            name='GridCategory',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(max_length=255)),
            ],
        ),
        migrations.CreateModel(
            name='GridCategoryGridItem',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('sort_order', models.IntegerField(blank=True, editable=False, null=True)),
                ('category', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='+', to='wagtailgridder.GridCategory')),
            ],
            options={
                'ordering': ['sort_order'],
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='GridIndexGridItemRelationship',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('sort_order', models.IntegerField(blank=True, editable=False, null=True)),
            ],
            options={
                'ordering': ['sort_order'],
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='GridIndexPage',
            fields=[
                ('page_ptr', models.OneToOneField(auto_created=True, on_delete=django.db.models.deletion.CASCADE, parent_link=True, primary_key=True, serialize=False, to='wagtailcore.Page')),
            ],
            options={
                'verbose_name': 'Grid Index Page',
            },
            bases=('wagtailcore.page',),
        ),
        migrations.CreateModel(
            name='GridItem',
            fields=[
                ('page_ptr', models.OneToOneField(auto_created=True, on_delete=django.db.models.deletion.CASCADE, parent_link=True, primary_key=True, serialize=False, to='wagtailcore.Page')),
                ('summary', wagtail.wagtailcore.fields.RichTextField(default='', help_text='The summary will appear in the item "card" view.', verbose_name='Summary')),
                ('full_desc', wagtail.wagtailcore.fields.RichTextField(default='', help_text='The description will appear when the grid item is clicked and expanded.', verbose_name='Full Description')),
                ('target_url', models.URLField(blank=True, default='', help_text='The URL for this grid item, if it is not a full Django App.', verbose_name='URL')),
                ('modified', models.DateTimeField(null=True, verbose_name='Page Modified')),
                ('buttons', wagtail.wagtailcore.fields.StreamField((('button_section', wagtail.wagtailcore.blocks.StructBlock((('action_items', wagtail.wagtailcore.blocks.StreamBlock((('document_button', wagtail.wagtailcore.blocks.StructBlock((('label', wagtail.wagtailcore.blocks.TextBlock(required=True)), ('document', wagtail.wagtaildocs.blocks.DocumentChooserBlock(required=True))), icon='fa-file')), ('url_button', wagtail.wagtailcore.blocks.StructBlock((('label', wagtail.wagtailcore.blocks.TextBlock(required=True)), ('url', wagtail.wagtailcore.blocks.URLBlock(required=True))), icon='fa-link')), ('placeholder', wagtail.wagtailcore.blocks.StructBlock((), icon='fa-square-o'))), help_text='A button or URL within a button section.')),))),), null=True)),
                ('main_image', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='+', to='wagtailimages.Image')),
                ('small_image', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='+', to='wagtailimages.Image')),
            ],
            options={
                'verbose_name': 'Grid Item',
            },
            bases=('wagtailcore.page',),
        ),
        migrations.CreateModel(
            name='GridItemTag',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('content_object', modelcluster.fields.ParentalKey(on_delete=django.db.models.deletion.CASCADE, related_name='tagged_items', to='wagtailgridder.GridItem')),
                ('tag', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='wagtailgridder_griditemtag_items', to='taggit.Tag')),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.AddField(
            model_name='griditem',
            name='tags',
            field=modelcluster.contrib.taggit.ClusterTaggableManager(blank=True, help_text='A comma-separated list of tags.', through='wagtailgridder.GridItemTag', to='taggit.Tag', verbose_name='Tags'),
        ),
        migrations.AddField(
            model_name='gridindexgriditemrelationship',
            name='GridRelationship',
            field=modelcluster.fields.ParentalKey(on_delete=django.db.models.deletion.CASCADE, related_name='grid_index_grid_item_relationship', to='wagtailgridder.GridIndexPage'),
        ),
        migrations.AddField(
            model_name='gridindexgriditemrelationship',
            name='grid_item',
            field=models.ForeignKey(help_text='Add a grid item to the page', on_delete=django.db.models.deletion.CASCADE, related_name='+', to='wagtailgridder.GridItem', verbose_name='Grid Items'),
        ),
        migrations.AddField(
            model_name='gridcategorygriditem',
            name='page',
            field=modelcluster.fields.ParentalKey(on_delete=django.db.models.deletion.CASCADE, related_name='categories', to='wagtailgridder.GridItem'),
        ),
    ]



from django.db import models
from django.forms import CheckboxSelectMultiple
from django.utils import timezone

from wagtail.wagtailcore.fields import StreamField, RichTextField
from wagtail.wagtailcore.models import Page, Orderable
from wagtail.wagtailadmin.edit_handlers import FieldPanel, StreamFieldPanel, PageChooserPanel, InlinePanel, MultiFieldPanel
from wagtail.wagtailimages.edit_handlers import ImageChooserPanel
from wagtail.wagtailsearch import index

from modelcluster.fields import ParentalKey, ParentalManyToManyField
from modelcluster.tags import ClusterTaggableManager
from taggit.models import TaggedItemBase

from .blocks import ButtonBlock


class GridItemTag(TaggedItemBase):
    """
    Object to hold existing tags for Grid Items.
    """

    content_object = ParentalKey('GridItem', related_name='tagged_items')


class GridCategory(models.Model):
    """
    Categories which a grid item can belong to. A grid item can belong to
    many categories. Categories can be selected from the top of the grid
    index page.
    """

    name = models.CharField(max_length=255)

    def __str__(self):
        return self.name

    class Meta:
        verbose_name_plural = 'grid categories'


class GridItem(Page):
    """
    The fields needed to properly display a grid item.
    The template will omit any fields not included automagically.
    """

    class Meta:
        verbose_name = "Grid Item"

    summary_image = models.ForeignKey(
        'wagtailimages.Image',
        null=True,
        blank=True,
        on_delete=models.SET_NULL,
        related_name='+',
    )
    summary_text = RichTextField(
        'Summary',
        default='',
        help_text='The summary will appear in the item "card" view.',
    )
    description_image = models.ForeignKey(
        'wagtailimages.Image',
        null=True,
        blank=True,
        on_delete=models.SET_NULL,
        related_name='+',
        help_text='This image will appear in the expanded area when populated.',
    )
    description_text = RichTextField(
        'Full Description',
        null=True,
        blank=True,
        help_text='This description will appear in the expanded area when populated.',
    )
    description_video = models.URLField(
        null=True,
        blank=True,
        help_text='This video will be embedded in the expanded area when populated.',
    )
    landing_page_text = RichTextField(
        'Landing Page Text',
        null=True,
        blank=True,
        help_text='This is the text which will appear on the grid item\'s landing page.',
    )
    buttons = StreamField(ButtonBlock(), null=True)
    tags = ClusterTaggableManager(through=GridItemTag, blank=True)
    categories = ParentalManyToManyField('GridCategory', blank=True)
    modified = models.DateTimeField('Page Modified', null=True)

    search_fields = Page.search_fields + [
        index.SearchField('summary_text'),
        index.SearchField('description_text'),
        index.SearchField('landing_page_text'),
    ]

    CARD_PANELS = [
        ImageChooserPanel('summary_image'),
        FieldPanel('summary_text'),
    ]

    DETAIL_PANELS = [
        ImageChooserPanel('description_image'),
        FieldPanel('description_text'),
        FieldPanel('description_video'),
        FieldPanel('landing_page_text'),
    ]

    META_PANELS = [
        FieldPanel('tags'),
        FieldPanel('categories', widget=CheckboxSelectMultiple),
    ]

    content_panels = Page.content_panels + [
        MultiFieldPanel(
            CARD_PANELS,
            heading="Card Information",
            classname="collapsible",
        ),
        MultiFieldPanel(
            DETAIL_PANELS,
            heading="Expanded Description & Page Information",
            classname="collapsible",
        ),
        StreamFieldPanel(
            'buttons',
        ),
        MultiFieldPanel(
            META_PANELS,
            heading="Metadata",
            classname="collapsible",
        ),
    ]

    def save(self, *args, **kwargs):
        self.modified = timezone.now()
        super(GridItem, self).save(*args, **kwargs)


class GridIndexGridItemRelationship(Orderable, models.Model):
    """
    Allows the content creator to associate Grid Items on a
    Grid Index Page.
    """

    grid_relationship = ParentalKey(
        'GridIndexPage',
        related_name='grid_index_grid_item_relationship'
    )
    grid_item = models.ForeignKey(
        'GridItem',
        related_name="+",
        help_text='Add a grid item to the page',
        verbose_name='Grid Items'
    )
    panels = [
        PageChooserPanel('grid_item')
    ]


class GridIndexPage(Page):
    """
    Index page for Grid Items.
    This links the grid items to the categories and provides a page to display them on.
    """

    hero_background_image = models.ForeignKey(
        'wagtailimages.Image',
        null=True,
        blank=True,
        on_delete=models.SET_NULL,
        related_name='+',
        help_text='The background image for the hero section. This triggers the section to be displayed if an image is selected.',
    )

    hero_logo_image = models.ForeignKey(
        'wagtailimages.Image',
        null=True,
        blank=True,
        on_delete=models.SET_NULL,
        related_name='+',
        help_text='The logo image to be displayed over the background image.',
    )

    hero_description = models.TextField(
        null=True,
        blank=True,
        help_text='Text to be displayed beneath the logo over the background image.',
    )

    hero_button_text = models.CharField(
        null=True,
        blank=True,
        max_length=255,
        help_text='Text for the call-to-action button beneath the text and logo over the background image.',
    )

    hero_button_url = models.CharField(
        null=True,
        blank=True,
        max_length=255,
        help_text='URL for the call-to-action button beneath the text and logo over the background image.',
    )

    featured_description = models.TextField(
        null=True,
        blank=True,
        help_text='Text to be displayed below the hero image next to the featured items.',
    )

    featured_grid_item_1 = models.ForeignKey(
        'GridItem',
        null=True,
        blank=True,
        on_delete=models.SET_NULL,
        related_name="+",
        help_text='First featured grid item underneath the hero image.',
        verbose_name='Featured Item One',
    )

    featured_grid_item_2 = models.ForeignKey(
        'GridItem',
        null=True,
        blank=True,
        on_delete=models.SET_NULL,
        related_name="+",
        help_text='Second featured grid item underneath the hero image.',
        verbose_name='Featured Item Two,'
    )

    @property
    def grid_items(self):
        grid_items = [
            n.grid_item for n in self.grid_index_grid_item_relationship.all()
        ]
        return grid_items

    @property
    def categories(self):
        grid_item_categories = GridIndexGridItemRelationship.objects.values_list(
            'grid_item__categories__name'
        ).filter(
            grid_relationship__id=self.id,
        ).order_by(
            'grid_item__categories__name',
        ).distinct()

        categories = []

        for gic in grid_item_categories:
            if gic[0] is not None:
                categories.append(gic[0])

        return categories

    HERO_PANELS = [
        ImageChooserPanel('hero_background_image'),
        ImageChooserPanel('hero_logo_image'),
        FieldPanel('hero_description'),
        FieldPanel('hero_button_text'),
        FieldPanel('hero_button_url'),
        FieldPanel('featured_description'),
        PageChooserPanel('featured_grid_item_1'),
        PageChooserPanel('featured_grid_item_2'),
    ]

    content_panels = Page.content_panels + [
        MultiFieldPanel(
            HERO_PANELS,
            heading="Hero Section (Optional)",
            classname="collapsible collapsed",
        ),
        InlinePanel(
            'grid_index_grid_item_relationship',
            label="grid_items",
            panels=None,
            min_num=1
        ),
    ]

    search_fields = Page.search_fields + [
        index.SearchField('grid_index_grid_item_relationship'),
    ]

    # Don't allow child pages to be added
    subpage_types = [
    ]

    class Meta:
        verbose_name = "Grid Index Page"

    def __str__(self):
        return '{0}'.format(
            self.grid_items,
        )



# -*- coding: utf-8 -*-
# Generated by Django 1.10.3 on 2016-11-17 12:15
from __future__ import unicode_literals

from django.db import migrations
import wagtail.wagtailcore.blocks
import wagtail.wagtailcore.fields
import wagtail.wagtaildocs.blocks


class Migration(migrations.Migration):

    dependencies = [
        ('wagtailgridder', '0004_auto_20161103_1446'),
    ]

    operations = [
        migrations.AlterField(
            model_name='griditem',
            name='buttons',
            field=wagtail.wagtailcore.fields.StreamField((('button_section', wagtail.wagtailcore.blocks.StructBlock((('action_items', wagtail.wagtailcore.blocks.StreamBlock((('document_button', wagtail.wagtailcore.blocks.StructBlock((('label', wagtail.wagtailcore.blocks.TextBlock(required=True)), ('document', wagtail.wagtaildocs.blocks.DocumentChooserBlock(required=True))), icon='fa-file')), ('url_button', wagtail.wagtailcore.blocks.StructBlock((('label', wagtail.wagtailcore.blocks.TextBlock(required=True)), ('url', wagtail.wagtailcore.blocks.TextBlock(required=True))), icon='fa-link')), ('placeholder', wagtail.wagtailcore.blocks.StructBlock((), icon='fa-square-o'))), help_text='A button or URL within a button section.')),))),), null=True),
        ),
    ]



# -*- coding: utf-8 -*-
# Generated by Django 1.10.5 on 2017-02-17 14:04
from __future__ import unicode_literals

from django.db import migrations
import modelcluster.fields


class Migration(migrations.Migration):

    dependencies = [
        ('wagtailgridder', '0006_auto_20170217_1354'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='gridcategory',
            options={'verbose_name_plural': 'grid categories'},
        ),
        migrations.AddField(
            model_name='griditem',
            name='categories',
            field=modelcluster.fields.ParentalManyToManyField(blank=True, to='wagtailgridder.GridCategory'),
        ),
    ]



# -*- coding: utf-8 -*-
# Generated by Django 1.10.1 on 2016-10-14 13:52
from __future__ import unicode_literals

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('wagtailgridder', '0002_griditem_landing_page_text'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='griditem',
            name='target_url',
        ),
    ]



# -*- coding: utf-8 -*-
# Generated by Django 1.10.5 on 2017-02-17 13:54
from __future__ import unicode_literals

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('wagtailgridder', '0005_auto_20161117_0715'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='gridcategorygriditem',
            name='category',
        ),
        migrations.RemoveField(
            model_name='gridcategorygriditem',
            name='page',
        ),
        migrations.RemoveField(
            model_name='griditem',
            name='landing_page_image',
        ),
        migrations.DeleteModel(
            name='GridCategoryGridItem',
        ),
    ]



from django.core.cache import cache

from wagtail.contrib.modeladmin.options import (
    ModelAdmin, ModelAdminGroup, modeladmin_register
)
from wagtail.wagtailcore import hooks

from .models import (
    GridCategory, GridIndexPage
)
from .settings import get_clear_cache


class GridCategoryAdmin(ModelAdmin):
    model = GridCategory
    menu_label = 'Grid Categories'
    menu_icon = 'fa-folder-open'
    add_to_settings_menu = False
    list_display = ('name',)
    search_fields = ('name',)


class GridIndexPageAdmin(ModelAdmin):
    model = GridIndexPage
    menu_icon = 'doc-full-inverse'
    list_display = ('title',)
    search_fields = ('title',)


class GridAdminGroup(ModelAdminGroup):
    menu_label = 'Grid Layouts'
    menu_icon = 'fa-th'  # change as required
    menu_order = 400  # will put in 3rd place (000 being 1st, 100 2nd)
    items = (GridCategoryAdmin, GridIndexPageAdmin)


modeladmin_register(GridAdminGroup)


@hooks.register('after_edit_page')
def clear_page_cache(request, page):
    """
    This will clear Django's entire cache after a page edit. It is ugly,
    but Django's cache mechanism doesn't currently support a way to easily
    depending on the value of is_staff() and (if present) is_faculty.
    """

    if get_clear_cache():
        cache.clear()



# -*- coding: utf-8 -*-
# Generated by Django 1.10.6 on 2017-04-03 13:47
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('wagtailgridder', '0009_gridindexpage_logo_image'),
    ]

    operations = [
        migrations.RenameField(
            model_name='gridindexpage',
            old_name='hero_image',
            new_name='hero_background_image',
        ),
        migrations.RenameField(
            model_name='gridindexpage',
            old_name='logo_image',
            new_name='hero_logo_image',
        ),
        migrations.AddField(
            model_name='gridindexpage',
            name='featured_description',
            field=models.TextField(blank=True, null=True),
        ),
        migrations.AddField(
            model_name='gridindexpage',
            name='hero_button_text',
            field=models.CharField(blank=True, max_length=255, null=True),
        ),
        migrations.AddField(
            model_name='gridindexpage',
            name='hero_button_url',
            field=models.CharField(blank=True, max_length=255, null=True),
        ),
        migrations.AddField(
            model_name='gridindexpage',
            name='hero_description',
            field=models.TextField(blank=True, null=True),
        ),
    ]



# -*- coding: utf-8 -*-
# Generated by Django 1.10.2 on 2016-10-13 14:19
from __future__ import unicode_literals

from django.db import migrations
import wagtail.wagtailcore.fields


class Migration(migrations.Migration):

    dependencies = [
        ('wagtailgridder', '0001_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='griditem',
            name='landing_page_text',
            field=wagtail.wagtailcore.fields.RichTextField(default='', help_text="This is the text which will appear on the grid item's landing page.", verbose_name='Landing Page Text'),
        ),
    ]



# -*- coding: utf-8 -*-
# Generated by Django 1.10.2 on 2016-11-03 18:46
from __future__ import unicode_literals

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('wagtailimages', '0013_make_rendition_upload_callable'),
        ('wagtailgridder', '0003_remove_griditem_target_url'),
    ]

    operations = [
        migrations.RenameField(
            model_name='griditem',
            old_name='main_image',
            new_name='description_image',
        ),
        migrations.RenameField(
            model_name='griditem',
            old_name='full_desc',
            new_name='description_text',
        ),
        migrations.RenameField(
            model_name='griditem',
            old_name='small_image',
            new_name='summary_image',
        ),
        migrations.RenameField(
            model_name='griditem',
            old_name='summary',
            new_name='summary_text',
        ),
        migrations.AddField(
            model_name='griditem',
            name='landing_page_image',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='+', to='wagtailimages.Image'),
        ),
    ]



# -*- coding: utf-8 -*-
# Generated by Django 1.10.6 on 2017-04-04 14:54
from __future__ import unicode_literals

from django.db import migrations, models
import django.db.models.deletion
import wagtail.wagtailcore.fields


class Migration(migrations.Migration):

    dependencies = [
        ('wagtailgridder', '0010_auto_20170403_1347'),
    ]

    operations = [
        migrations.AddField(
            model_name='griditem',
            name='description_video',
            field=models.URLField(blank=True, help_text='This video will be embedded in the expanded area when populated.', null=True),
        ),
        migrations.AlterField(
            model_name='gridindexpage',
            name='featured_description',
            field=models.TextField(blank=True, help_text='Text to be displayed below the hero image next to the featured items.', null=True),
        ),
        migrations.AlterField(
            model_name='gridindexpage',
            name='featured_grid_item_1',
            field=models.ForeignKey(blank=True, help_text='First featured grid item underneath the hero image.', null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='+', to='wagtailgridder.GridItem', verbose_name='Featured Item One'),
        ),
        migrations.AlterField(
            model_name='gridindexpage',
            name='featured_grid_item_2',
            field=models.ForeignKey(blank=True, help_text='Second featured grid item underneath the hero image.', null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='+', to='wagtailgridder.GridItem', verbose_name='Featured Item Two,'),
        ),
        migrations.AlterField(
            model_name='gridindexpage',
            name='hero_background_image',
            field=models.ForeignKey(blank=True, help_text='The background image for the hero section. This triggers the section to be displayed if an image is selected.', null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='+', to='wagtailimages.Image'),
        ),
        migrations.AlterField(
            model_name='gridindexpage',
            name='hero_button_text',
            field=models.CharField(blank=True, help_text='Text for the call-to-action button beneath the text and logo over the background image.', max_length=255, null=True),
        ),
        migrations.AlterField(
            model_name='gridindexpage',
            name='hero_button_url',
            field=models.CharField(blank=True, help_text='URL for the call-to-action button beneath the text and logo over the background image.', max_length=255, null=True),
        ),
        migrations.AlterField(
            model_name='gridindexpage',
            name='hero_description',
            field=models.TextField(blank=True, help_text='Text to be displayed beneath the logo over the background image.', null=True),
        ),
        migrations.AlterField(
            model_name='gridindexpage',
            name='hero_logo_image',
            field=models.ForeignKey(blank=True, help_text='The logo image to be displayed over the background image.', null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='+', to='wagtailimages.Image'),
        ),
        migrations.AlterField(
            model_name='griditem',
            name='description_image',
            field=models.ForeignKey(blank=True, help_text='This image will appear in the expanded area when populated.', null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='+', to='wagtailimages.Image'),
        ),
        migrations.AlterField(
            model_name='griditem',
            name='description_text',
            field=wagtail.wagtailcore.fields.RichTextField(blank=True, help_text='This description will appear in the expanded area when populated.', null=True, verbose_name='Full Description'),
        ),
        migrations.AlterField(
            model_name='griditem',
            name='landing_page_text',
            field=wagtail.wagtailcore.fields.RichTextField(blank=True, help_text="This is the text which will appear on the grid item's landing page.", null=True, verbose_name='Landing Page Text'),
        ),
    ]



# -*- coding: utf-8 -*-
# Generated by Django 1.11.2 on 2017-06-07 17:17
from __future__ import unicode_literals

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('wagtailgridder', '0011_auto_20170404_1454'),
    ]

    operations = [
        migrations.RenameField(
            model_name='gridindexgriditemrelationship',
            old_name='GridRelationship',
            new_name='grid_relationship',
        ),
    ]



# -*- coding: utf-8 -*-
# Generated by Django 1.10.6 on 2017-03-20 17:07
from __future__ import unicode_literals

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('wagtailimages', '0018_remove_rendition_filter'),
        ('wagtailgridder', '0007_auto_20170217_1404'),
    ]

    operations = [
        migrations.AddField(
            model_name='gridindexpage',
            name='featured_grid_item_1',
            field=models.ForeignKey(blank=True, help_text='Add a featured grid item to the page', null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='+', to='wagtailgridder.GridItem', verbose_name='Grid Items'),
        ),
        migrations.AddField(
            model_name='gridindexpage',
            name='featured_grid_item_2',
            field=models.ForeignKey(blank=True, help_text='Add a second featured grid item to the page', null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='+', to='wagtailgridder.GridItem', verbose_name='Grid Items'),
        ),
        migrations.AddField(
            model_name='gridindexpage',
            name='hero_image',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='+', to='wagtailimages.Image'),
        ),
    ]
